==> ask-cli-1.1.1.tgz: package/lib/api/account-linking.js <==
'use strict';

const apiWrapper = require('./api-wrapper');
const tools = require('../utils/tools');
const inquirer = require('inquirer');
const profileHelper = require('../utils/profile-helper');
const CONSTANTS = require('../utils/constants');

// Public
module.exports = {
    createCommand: (commander) => {
        buildCreateAccountLinkingCommand(commander);
        buildGetAccountLinkingCommand(commander);
        buildDeleteAccountLinkingCommand(commander);
    }
};

// Private
function buildCreateAccountLinkingCommand(commander) {
    commander
        .command('create-account-linking')
        .usage('<-s|--skill-id <skill-id>> <-g|--stage <stage>> [-p|--profile <profile>] [--debug]')
        .description('create/update account linking configuration for a skill')
        .option('-s, --skill-id <skill-id>', 'skill-id for the skill')
        .option('-g, --stage <stage>', 'stage for the skill')
        .option('-p, --profile <profile>', 'ask cli profile')
        .option('--debug', 'ask cli debug mode')
        .action(handle);

    function handle(options) {
        if (!options.skillId) {
            console.warn('Please input required parameter: skill-id.');
            return;
        }
        let stage = options.stage || CONSTANTS.SKILL.STAGE.DEVELOPMENT;
        let accountLinking = {};
        let profile = profileHelper.runtimeProfile(options.profile);
        collectAccountLinkingAnswers(accountLinking, (accountLinking) => {
            apiWrapper.callCreateAccountLinking(options.skillId, stage, accountLinking, profile, options.debug, () => {
                console.log('Account Linking created successfully.');
            });
        });
    }
}

function buildGetAccountLinkingCommand(commander) {
    commander
        .command('get-account-linking')
        .usage('<-s|--skill-id <skill-id>> <-g|--stage <stage>> [-p|--profile <profile>] [--debug]')
        .description('get account linking configuration for a skill')
        .option('-s, --skill-id <skill-id>', 'skill-id for the skill')
        .option('-g, --stage <stage>', 'stage for the skill')
        .option('-p, --profile <profile>', 'ask cli profile')
        .option('--debug', 'ask cli debug mode')
        .action(handle);

    function handle(options) {
        if (!options.skillId) {
            console.warn('Please input required parameter: skill-id.');
            return;
        }
        let stage = options.stage || CONSTANTS.SKILL.STAGE.DEVELOPMENT;
        let profile = profileHelper.runtimeProfile(options.profile);
        apiWrapper.callGetAccountLinking(options.skillId, stage, profile, options.debug, (data) => {
            let response = tools.convertDataToJsonObject(data.body);
            if (response) {
                console.log(JSON.stringify(response, null, 2));
            }
        });
    }
}

function buildDeleteAccountLinkingCommand(commander) {
    commander
        .command('delete-account-linking')
        .usage('<-s|--skill-id <skill-id>> <-g|--stage <stage>> [-p|--profile <profile>] [--debug]')
        .description('delete account linking configuration for a skill')
        .option('-s, --skill-id <skill-id>', 'skill-id for the skill')
        .option('-g, --stage <stage>', 'stage for the skill')
        .option('-p, --profile <profile>', 'ask cli profile')
        .option('--debug', 'ask cli debug mode')
        .action(handle);

    function handle(options) {
        if (!options.skillId) {
            console.warn('Please input required parameter: skill-id.');
            return;
        }
        let stage = options.stage || CONSTANTS.SKILL.STAGE.DEVELOPMENT;
        let profile = profileHelper.runtimeProfile(options.profile);
        apiWrapper.callDeleteAccountLinking(options.skillId, stage, profile, options.debug, () => {
            console.log('Account linking removed successfully.');
        });
    }
}

function collectAccountLinkingAnswers(accountLinking, callback) {
    let question1 = [
        {
            type: 'input',
            name: 'authorizationUrl',
            message: 'Authorization URL: '
        },
        {
            type: 'input',
            name: 'clientId',
            message: 'Client ID: '
        },
        {
            type: 'input',
            name: 'scopes',
            message: 'Scopes(separate by comma): '
        },
        {
            type: 'input',
            name: 'domains',
            message: 'Domains(separate by comma): '
        }
    ];
    inquirer.prompt(question1).then((answers) => {
        accountLinking.authorizationUrl = answers.authorizationUrl;
        accountLinking.clientId = answers.clientId;

        let tempScopes = answers.scopes.split(',')
            .map((scope) => {
                return scope.trim();
            })
            .filter((item) => {
                if (item.length > 0) {
                    return item;
                } else {
                    return null;
                }
            });
        accountLinking.scopes = tempScopes.length ? tempScopes : null;

        let tempDomains = answers.domains.split(',')
            .map((domain) => {
                return domain.trim();
            })
            .filter((item) => {
                if (item.length > 0) {
                    return item;
                } else {
                    return null;
                }
            });
        accountLinking.domains = tempDomains.length ? tempDomains : null;

        let question2 = {
            type: 'list',
            name: 'type',
            message: 'Authorization Grant Type: ',
            choices: [
                'AUTH_CODE',
                'IMPLICIT'
            ]
        };
        inquirer.prompt(question2).then((answers) => {
            accountLinking.type = answers.type;
            if (answers.type !== 'AUTH_CODE') {
                callback(accountLinking);
            } else {
                let question3 = [
                    {
                        type: 'input',
                        name: 'accessTokenUrl',
                        message: 'Access Token URI: '
                    },
                    {
                        type: 'password',
                        name: 'clientSecret',
                        message: 'Client Secret: ',
                        validate: function (input) {
                            if (!input) {
                                return "'Client Secret' cannot be empty.";
                            }
                            return true;
                        }
                    },
                    {
                        type: 'list',
                        name: 'accessTokenScheme',
                        message: 'Client Authentication Scheme: ',
                        choices: [
                            'HTTP_BASIC',
                            'REQUEST_BODY_CREDENTIALS'
                        ]
                    },
                    {
                        type: 'input',
                        name: 'defaultTokenExpirationInSeconds',
                        message: 'Optional* Default Access Token Expiration Time In Seconds: ',
                        validate: function (input) {
                            try{
                                // no input is ok
                                if (!input) {
                                    return true;
                                }

                                // test if input can be transformed into an integer
                                let result = parseInt(input);
                                if (isNaN(result)) {
                                    return "Token expiration time should be an integer.";
                                }

                                // the integer has to be greater than 0
                                if (result < 0) {
                                    return "Token expiration time cannot be set to a value less than 0.";
                                }
                                return true;
                            } catch (e) {
                                // in some cases, parseInt with string will throw error instead of NaN.
                                return "defaultTokenExpirationInSeconds can only be an integer.";
                            }
                        }
                    }
                ];
                inquirer.prompt(question3).then((answers) => {
                    accountLinking.accessTokenUrl = answers.accessTokenUrl;
                    accountLinking.clientSecret = answers.clientSecret;
                    accountLinking.accessTokenScheme = answers.accessTokenScheme;
                    if (answers.defaultTokenExpirationInSeconds) {
                        accountLinking.defaultTokenExpirationInSeconds = parseInt(answers.defaultTokenExpirationInSeconds);
                    }
                    callback(accountLinking);
                });
            }
        });
    });
}

==> ask-cli-1.3.0.tgz: package/lib/api/account-linking.js <==
'use strict';

const apiWrapper = require('./api-wrapper');
const tools = require('../utils/tools');
const inquirer = require('inquirer');
const profileHelper = require('../utils/profile-helper');
const CONSTANTS = require('../utils/constants');

// Public
module.exports = {
    createCommand: (commander) => {
        buildCreateAccountLinkingCommand(commander);
        buildGetAccountLinkingCommand(commander);
        buildDeleteAccountLinkingCommand(commander);
    }
};

// Private
function buildCreateAccountLinkingCommand(commander) {
    commander
        .command('create-account-linking')
        .usage('<-s|--skill-id <skill-id>> [-g|--stage <stage>] [-p|--profile <profile>] [--debug]')
        .description('create/update account linking configuration for a skill')
        .option('-s, --skill-id <skill-id>', 'skill-id for the skill')
        .option('-g, --stage <stage>', 'stage for the skill')
        .option('-p, --profile <profile>', 'ask cli profile')
        .option('--debug', 'ask cli debug mode')
        .action(handle);

    function handle(options) {
        if (!options.skillId) {
            console.warn('Please input required parameter: skill-id.');
            return;
        }
        let stage = options.stage || CONSTANTS.SKILL.STAGE.DEVELOPMENT;
        let accountLinking = {};
        let profile = profileHelper.runtimeProfile(options.profile);
        collectAccountLinkingAnswers(accountLinking, (accountLinking) => {
            apiWrapper.callCreateAccountLinking(options.skillId, stage, accountLinking, profile, options.debug, () => {
                console.log('Account Linking created successfully.');
            });
        });
    }
}

function buildGetAccountLinkingCommand(commander) {
    commander
        .command('get-account-linking')
        .usage('<-s|--skill-id <skill-id>> [-g|--stage <stage>] [-p|--profile <profile>] [--debug]')
        .description('get account linking configuration for a skill')
        .option('-s, --skill-id <skill-id>', 'skill-id for the skill')
        .option('-g, --stage <stage>', 'stage for the skill')
        .option('-p, --profile <profile>', 'ask cli profile')
        .option('--debug', 'ask cli debug mode')
        .action(handle);

    function handle(options) {
        if (!options.skillId) {
            console.warn('Please input required parameter: skill-id.');
            return;
        }
        let stage = options.stage || CONSTANTS.SKILL.STAGE.DEVELOPMENT;
        let profile = profileHelper.runtimeProfile(options.profile);
        apiWrapper.callGetAccountLinking(options.skillId, stage, profile, options.debug, (data) => {
            let response = tools.convertDataToJsonObject(data.body);
            if (response) {
                console.log(JSON.stringify(response, null, 2));
            }
        });
    }
}

function buildDeleteAccountLinkingCommand(commander) {
    commander
        .command('delete-account-linking')
        .usage('<-s|--skill-id <skill-id>> [-g|--stage <stage>] [-p|--profile <profile>] [--debug]')
        .description('delete account linking configuration for a skill')
        .option('-s, --skill-id <skill-id>', 'skill-id for the skill')
        .option('-g, --stage <stage>', 'stage for the skill')
        .option('-p, --profile <profile>', 'ask cli profile')
        .option('--debug', 'ask cli debug mode')
        .action(handle);

    function handle(options) {
        if (!options.skillId) {
            console.warn('Please input required parameter: skill-id.');
            return;
        }
        let stage = options.stage || CONSTANTS.SKILL.STAGE.DEVELOPMENT;
        let profile = profileHelper.runtimeProfile(options.profile);
        apiWrapper.callDeleteAccountLinking(options.skillId, stage, profile, options.debug, () => {
            console.log('Account linking removed successfully.');
        });
    }
}

function collectAccountLinkingAnswers(accountLinking, callback) {
    let question1 = [
        {
            type: 'input',
            name: 'authorizationUrl',
            message: 'Authorization URL: '
        },
        {
            type: 'input',
            name: 'clientId',
            message: 'Client ID: '
        },
        {
            type: 'input',
            name: 'scopes',
            message: 'Scopes(separate by comma): '
        },
        {
            type: 'input',
            name: 'domains',
            message: 'Domains(separate by comma): '
        }
    ];
    inquirer.prompt(question1).then((answers) => {
        accountLinking.authorizationUrl = answers.authorizationUrl;
        accountLinking.clientId = answers.clientId;

        let tempScopes = answers.scopes.split(',')
            .map((scope) => {
                return scope.trim();
            })
            .filter((item) => {
                if (item.length > 0) {
                    return item;
                } else {
                    return null;
                }
            });
        accountLinking.scopes = tempScopes.length ? tempScopes : null;

        let tempDomains = answers.domains.split(',')
            .map((domain) => {
                return domain.trim();
            })
            .filter((item) => {
                if (item.length > 0) {
                    return item;
                } else {
                    return null;
                }
            });
        accountLinking.domains = tempDomains.length ? tempDomains : null;

        let question2 = {
            type: 'list',
            name: 'type',
            message: 'Authorization Grant Type: ',
            choices: [
                'AUTH_CODE',
                'IMPLICIT'
            ]
        };
        inquirer.prompt(question2).then((answers) => {
            accountLinking.type = answers.type;
            if (answers.type !== 'AUTH_CODE') {
                callback(accountLinking);
            } else {
                let question3 = [
                    {
                        type: 'input',
                        name: 'accessTokenUrl',
                        message: 'Access Token URI: '
                    },
                    {
                        type: 'password',
                        name: 'clientSecret',
                        message: 'Client Secret: ',
                        validate: function (input) {
                            if (!input.trim()) {
                                return "'Client Secret' cannot be empty.";
                            }
                            return true;
                        }
                    },
                    {
                        type: 'list',
                        name: 'accessTokenScheme',
                        message: 'Client Authentication Scheme: ',
                        choices: [
                            'HTTP_BASIC',
                            'REQUEST_BODY_CREDENTIALS'
                        ]
                    },
                    {
                        type: 'input',
                        name: 'defaultTokenExpirationInSeconds',
                        message: 'Optional* Default Access Token Expiration Time In Seconds: ',
                        validate: function (input) {
                            try{
                                // no input is ok
                                if (!input.trim()) {
                                    return true;
                                }

                                // test if input can be transformed into an integer
                                let result = parseInt(input);
                                if (isNaN(result)) {
                                    return "Token expiration time should be an integer.";
                                }

                                // the integer has to be greater than 0
                                if (result < 0) {
                                    return "Token expiration time cannot be set to a value less than 0.";
                                }
                                return true;
                            } catch (e) {
                                // in some cases, parseInt with string will throw error instead of NaN.
                                return "defaultTokenExpirationInSeconds can only be an integer.";
                            }
                        }
                    }
                ];
                inquirer.prompt(question3).then((answers) => {
                    accountLinking.accessTokenUrl = answers.accessTokenUrl;
                    accountLinking.clientSecret = answers.clientSecret;
                    accountLinking.accessTokenScheme = answers.accessTokenScheme;
                    if (answers.defaultTokenExpirationInSeconds) {
                        accountLinking.defaultTokenExpirationInSeconds = parseInt(answers.defaultTokenExpirationInSeconds);
                    }
                    callback(accountLinking);
                });
            }
        });
    });
}
